@@ -119,7 +119,7 @@ def get_base_embed(
     title: Optional[str] = discord.Embed.Empty,
     description: Optional[str] = discord.Embed.Empty,
     color: Optional[Union[discord.Color, tuple, str]] = discord.Color.dark_theme(),
-    timestamp: Optional[datetime.datetime] = datetime.datetime.utcnow(),
+    timestamp: Optional[Union[datetime.datetime, discord.Member, discord.Object]] = None,
     author: Optional[Union[discord.abc.User, discord.Guild]] = None,
     author_name: Optional[str] = None,
     author_icon: Optional[Union[discord.abc.User, discord.Guild, str]] = discord.Embed.Empty,
@@ -144,8 +144,11 @@ def get_base_embed(
     color : Optional Union(discord.Color, tuple, str)
         The color to use for the embed. Can be a `discord.Color` object, RGB tuple, or hex string.
         Defaults to `discord.Color.dark_theme()`
-    timestamp : Optional datetime.datetime
-        The utc timestamp to use for the embed (defaults to the current utc timestamp)
+    timestamp : Optional Union(datetime.datetime, discord.Member, discord.Object)
+        The utc timestamp, Discord member, or the Discord object to use for the embed.
+        If a `discord.Object` is supplied, the timestamp used will be the object's `created_at` timestamp.
+        If a `discord.Member` is supplied, the timestamp used will be the member's `joined_at` timestamp.
+        This defaults to the current UTC timestamp if none of the above are supplied
     author : Optional Union(discord.abc.User, discord.Guild)
         The user or guild to use for the embed author name/icon. This overrides both `author_name` and `author_icon`
     author_name : Optional str
@@ -162,7 +165,7 @@ def get_base_embed(
         The user or guild to use for the embed footer text/icon. This overrides both `footer_text` and `footer_icon`
     footer_text : Optional str
         The string to use for the footer text
-    footer_icon : Optional str
+    footer_icon : Optional Union(discord.abc.User, discord.Guild)
         The url to use for the embed footer icon
     url : Optional str
         The url to use for the embed (for when the title is clicked)
@@ -185,6 +188,14 @@ def get_base_embed(
     if title is Empty and description is Empty and color is Empty and author is None and author_name is None and thumbnail is None and image is None and footer is None and footer_text is Empty and footer_icon is Empty and url is None:
         raise ValueError("Cannot construct an empty base embed")
 
+    # convert timestamp to either a Discord member's joined_at or another Discord object's created_at timestamp
+    if isinstance(timestamp, discord.Member):
+        timestamp = timestamp.joined_at
+    elif isinstance(timestamp, discord.Object):
+        timestamp = discord.utils.snowflake_time(timestamp.id)
+    elif timestamp is None:
+        timestamp = datetime.datetime.utcnow()
+
     # set author icon
     if author_icon is not Empty:
         author_icon = get_image_url(author_icon)
@@ -227,9 +238,13 @@ def get_base_embed(
         )
     
     # set embed footer
-    if footer_text is not Empty and footer_icon is not Empty:
+    if footer_text is not Empty:
+        embed.set_footer(
+            text=footer_text
+        )
+    
+    if footer_icon is not Empty:
         embed.set_footer(
-            text=footer_text,
             icon_url=footer_icon
         )
     
@@ -249,19 +264,19 @@ def get_base_embed(
 
 
 async def paginate(
-        ctx: commands.Context,
-        embed_title: str,
-        line: str,
-        sequence: list,
-        embed_color: Optional[discord.Color] = discord.Color.dark_theme(),
-        prefix: Optional[str] = "",
-        suffix: Optional[str] = "",
-        max_page_size: Optional[int] = 2048,
-        other_sequence: Optional[list] = None,
-        sequence_type_name: Optional[str] = None,
-        author_name: Optional[str] = None,
-        author_icon_url: Optional[str] = None,
-        count_format: Optional[str] = None
+    ctx: commands.Context,
+    embed_title: str,
+    line: str,
+    sequence: list,
+    embed_color: Optional[discord.Color] = discord.Color.dark_theme(),
+    prefix: Optional[str] = "",
+    suffix: Optional[str] = "",
+    max_page_size: Optional[int] = 2048,
+    other_sequence: Optional[list] = None,
+    sequence_type_name: Optional[str] = None,
+    author_name: Optional[str] = None,
+    author_icon_url: Optional[str] = None,
+    count_format: Optional[str] = None
 ):
     """Creates a paginating menu given a particular context
 
@@ -405,4 +420,4 @@ async def paginate(
         elif react.emoji == far_right:
             index = len(paginator.pages) - 1
 
-        action = message.edit
\ No newline at end of file
+        action = message.edit
